@@ -166,6 +166,17 @@ def check_project_group(session):
 
     return True
 
+def check_find_result_without_duplicates(session):
+    """
+    Find the the composite Dummy entries as result set without duplicates.
+    """
+    dummy_entries = api.find_group(session, title="Dumm*", as_result=False)[0].entries
+    dummy_results = api.find_group(session, title="Dumm*", as_result=True)
+
+    assert len(dummy_results) == 1
+    assert len(dummy_entries) == 2
+
+    return True
 
 def check_composite_raises_error(session):
     with pytest.raises(TypeError) as excinfo:
@@ -338,6 +349,7 @@ def test_add_and_find():
     assert add_project_group(session)
     assert check_composite_raises_error(session)
     assert check_project_group(session)
+    assert check_find_result_without_duplicates(session)
     assert find_by_project(session)
     assert check_get_by_uuid(session)
     assert find_by_author(session)
